PAULE
=====
Predictive Articulatory speech synthesis Utilizing Lexical Embeddings (PAULE) a python frame work to plan control parameter trajectories for the VocalTractLab simulator for a target acoustics or semantic embedding.
